@@ -44,7 +44,26 @@ class TeleBot:
         sendChatAction
         getUserProfilePhotos
         getUpdates
-    """
+        getFile
+        kickChatMember
+        unbanChatMember
+        restrictChatMember
+        promoteChatMember
+        exportChatInviteLink
+        setChatPhoto
+        deleteChatPhoto
+        setChatTitle
+        setChatDescription
+        pinChatMessage
+        unpinChatMessage
+        leaveChat
+        getChat
+        getChatAdministrators
+        getChatMembersCount
+        getChatMember
+        answerCallbackQuery
+        answerInlineQuery
+        """
 
     def __init__(self, token, threaded=True, skip_pending=False, num_threads=2):
         """
@@ -601,18 +620,162 @@ class TeleBot:
         """
         return apihelper.send_chat_action(self.token, chat_id, action)
 
-    def kick_chat_member(self, chat_id, user_id):
+    def kick_chat_member(self, chat_id, user_id, until_date=None):
         """
         Use this method to kick a user from a group or a supergroup.
         :param chat_id: Int or string : Unique identifier for the target group or username of the target supergroup
         :param user_id: Int : Unique identifier of the target user
+        :param until_date: Date when the user will be unbanned, unix time. If user is banned for more than 366 days or
+               less than 30 seconds from the current time they are considered to be banned forever
         :return: types.Message
         """
-        return apihelper.kick_chat_member(self.token, chat_id, user_id)
+        return apihelper.kick_chat_member(self.token, chat_id, user_id, until_date)
 
     def unban_chat_member(self, chat_id, user_id):
         return apihelper.unban_chat_member(self.token, chat_id, user_id)
 
+    def restrict_chat_member(self, chat_id, user_id, until_date=None, can_send_messages=True,
+                             can_send_media_messages=True, can_send_other_messages=True,
+                             can_add_web_page_previews=True):
+        """
+        Use this method to restrict a user in a supergroup.
+        The bot must be an administrator in the supergroup for this to work and must have
+        the appropriate admin rights. Pass True for all boolean parameters to lift restrictions from a user.
+        Returns True on success.
+        :param chat_id: Int or String : 	Unique identifier for the target group or username of the target supergroup
+            or channel (in the format @channelusername)
+        :param user_id: Int : Unique identifier of the target user
+        :param until_date: Date when restrictions will be lifted for the user, unix time.
+            If user is restricted for more than 366 days or less than 30 seconds from the current time,
+            they are considered to be restricted forever
+        :param can_send_messages: Pass True, if the user can send text messages, contacts, locations and venues
+        :param can_send_media_messages Pass True, if the user can send audios, documents, photos, videos, video notes
+            and voice notes, implies can_send_messages
+        :param can_send_other_messages: Pass True, if the user can send animations, games, stickers and
+            use inline bots, implies can_send_media_messages
+        :param can_add_web_page_previews: Pass True, if the user may add web page previews to their messages,
+            implies can_send_media_messages
+        :return: types.Message
+        """
+        return apihelper.restrict_chat_member(self.token, chat_id, user_id, until_date, can_send_messages,
+                                              can_send_media_messages, can_send_other_messages,
+                                              can_add_web_page_previews)
+
+    def promote_chat_member(self, chat_id, user_id, can_change_info=False, can_post_messages=False,
+                            can_edit_messages=False, can_delete_messages=False, can_invite_users=False,
+                            can_restrict_members=False, can_pin_messages=False, can_promote_members=False):
+        """
+        Use this method to promote or demote a user in a supergroup or a channel. The bot must be an administrator
+        in the chat for this to work and must have the appropriate admin rights.
+        Pass False for all boolean parameters to demote a user. Returns True on success.
+        :param chat_id: Unique identifier for the target chat or username of the target channel (
+            in the format @channelusername)
+        :param user_id: Int : Unique identifier of the target user
+        :param can_change_info: Bool: Pass True, if the administrator can change chat title, photo and other settings
+        :param can_post_messages: Bool : Pass True, if the administrator can create channel posts, channels only
+        :param can_edit_messages: Bool : Pass True, if the administrator can edit messages of other users, channels only
+        :param can_delete_messages: Bool : Pass True, if the administrator can delete messages of other users
+        :param can_invite_users: Bool : Pass True, if the administrator can invite new users to the chat
+        :param can_restrict_members: Bool: Pass True, if the administrator can restrict, ban or unban chat members
+        :param can_pin_messages: Bool: Pass True, if the administrator can pin messages, supergroups only
+        :param can_promote_members: Bool: Pass True, if the administrator can add new administrators with a subset
+            of his own privileges or demote administrators that he has promoted, directly or indirectly
+            (promoted by administrators that were appointed by him)
+        :return:
+        """
+        return apihelper.promote_chat_member(self.token, chat_id, user_id, can_change_info, can_post_messages,
+                                             can_edit_messages, can_delete_messages, can_invite_users,
+                                             can_restrict_members, can_pin_messages, can_promote_members)
+
+    def export_chat_invite_link(self, chat_id):
+        """
+        Use this method to export an invite link to a supergroup or a channel. The bot must be an administrator
+        in the chat for this to work and must have the appropriate admin rights.
+        Returns exported invite link as String on success.
+        :param chat_id: Id: Unique identifier for the target chat or username of the target channel
+            (in the format @channelusername)
+        :return:
+        """
+        return apihelper.export_chat_invite_link(self.token, chat_id)
+
+    def set_chat_photo(self, chat_id, photo):
+        """
+        Use this method to set a new profile photo for the chat. Photos can't be changed for private chats.
+        The bot must be an administrator in the chat for this to work and must have the appropriate admin rights.
+        Returns True on success.
+        Note: In regular groups (non-supergroups), this method will only work if the ‘All Members Are Admins’
+            setting is off in the target group.
+        :param chat_id: Int or Str: Unique identifier for the target chat or username of the target channel
+            (in the format @channelusername)
+        :param photo: InputFile: New chat photo, uploaded using multipart/form-data
+        :return:
+        """
+        return apihelper.set_chat_photo(self.token, chat_id, photo)
+
+    def delete_chat_photo(self, chat_id):
+        """
+        Use this method to delete a chat photo. Photos can't be changed for private chats.
+        The bot must be an administrator in the chat for this to work and must have the appropriate admin rights.
+        Returns True on success.
+        Note: In regular groups (non-supergroups), this method will only work if the ‘All Members Are Admins’
+            setting is off in the target group.
+        :param chat_id: Int or Str: Unique identifier for the target chat or username of the target channel
+            (in the format @channelusername)
+        :return:
+        """
+        return apihelper.delete_chat_photo(self.token, chat_id)
+
+    def set_chat_title(self, chat_id, title):
+        """
+        Use this method to change the title of a chat. Titles can't be changed for private chats.
+        The bot must be an administrator in the chat for this to work and must have the appropriate admin rights.
+        Returns True on success.
+        Note: In regular groups (non-supergroups), this method will only work if the ‘All Members Are Admins’
+            setting is off in the target group.
+        :param chat_id: Int or Str: Unique identifier for the target chat or username of the target channel
+            (in the format @channelusername)
+        :param title: New chat title, 1-255 characters
+        :return:
+        """
+        return apihelper.set_chat_title(self.token, chat_id, title)
+
+    def set_chat_description(self, chat_id, description):
+        """
+        Use this method to change the description of a supergroup or a channel.
+        The bot must be an administrator in the chat for this to work and must have the appropriate admin rights.
+        Returns True on success.
+        :param chat_id: Int or Str: Unique identifier for the target chat or username of the target channel
+            (in the format @channelusername)
+        :param description: Str: New chat description, 0-255 characters
+        :return:
+        """
+        return apihelper.set_chat_description(self.token, chat_id, description)
+
+    def pin_chat_message(self, chat_id, message_id, disable_notification=False):
+        """
+        Use this method to pin a message in a supergroup.
+        The bot must be an administrator in the chat for this to work and must have the appropriate admin rights.
+        Returns True on success.
+        :param chat_id: Int or Str: Unique identifier for the target chat or username of the target channel
+            (in the format @channelusername)
+        :param message_id: Int: Identifier of a message to pin
+        :param disable_notification: Bool: Pass True, if it is not necessary to send a notification
+            to all group members about the new pinned message
+        :return:
+        """
+        return apihelper.pin_chat_message(self.token, chat_id, message_id, disable_notification)
+
+    def unpin_chat_message(self, chat_id):
+        """
+        Use this method to unpin a message in a supergroup chat.
+        The bot must be an administrator in the chat for this to work and must have the appropriate admin rights.
+        Returns True on success.
+        :param chat_id: Int or Str: Unique identifier for the target chat or username of the target channel
+            (in the format @channelusername)
+        :return:
+        """
+        return apihelper.unpin_chat_message(self.token, chat_id)
+
     def edit_message_text(self, text, chat_id=None, message_id=None, inline_message_id=None, parse_mode=None,
                           disable_web_page_preview=None, reply_markup=None):
         result = apihelper.edit_message_text(self.token, text, chat_id, message_id, inline_message_id, parse_mode,
@@ -661,7 +824,7 @@ class TeleBot:
         return types.Message.de_json(result)
 
     def answer_shipping_query(self, shipping_query_id, ok, shipping_options=None, error_message=None):
-        return apihelper.answer_shippingQuery(self.token, shipping_query_id, ok, shipping_options, error_message)
+        return apihelper.answer_shipping_query(self.token, shipping_query_id, ok, shipping_options, error_message)
 
     def answer_pre_checkout_query(self, pre_checkout_query_id, ok, error_message=None):
         return apihelper.answer_pre_checkout_query(self.token, pre_checkout_query_id, ok, error_message)
