@@ -1,5 +1,10 @@
 # -*- coding: utf-8 -*-
 
+try:
+    import ujson as json
+except ImportError:
+    import json
+
 import requests
 
 try:
@@ -14,6 +19,7 @@ from telebot import util
 
 logger = telebot.logger
 req_session = requests.session()
+proxy = None
 
 API_URL = "https://api.telegram.org/bot{0}/{1}"
 FILE_URL = "https://api.telegram.org/file/bot{0}/{1}"
@@ -42,7 +48,7 @@ def _make_request(token, method_name, method='get', params=None, files=None, bas
         if 'timeout' in params: read_timeout = params['timeout'] + 10
         if 'connect-timeout' in params: connect_timeout = params['connect-timeout'] + 10
     result = req_session.request(method, request_url, params=params, files=files,
-                                 timeout=(connect_timeout, read_timeout))
+                                 timeout=(connect_timeout, read_timeout), proxies=proxy)
     logger.debug("The server returned: '{0}'".format(result.text.encode('utf8')))
     return _check_result(method_name, result)['result']
 
@@ -137,7 +143,7 @@ def set_webhook(token, url=None, certificate=None, max_connections=None, allowed
     if max_connections:
         payload['max_connections'] = max_connections
     if allowed_updates:
-        payload['allowed_updates'] = allowed_updates
+        payload['allowed_updates'] = json.dumps(allowed_updates)
     return _make_request(token, method_url, params=payload, files=files)
 
 
@@ -162,7 +168,7 @@ def get_updates(token, offset=None, limit=None, timeout=None, allowed_updates=No
     if timeout:
         payload['timeout'] = timeout
     if allowed_updates:
-        payload['allowed_updates'] = allowed_updates
+        payload['allowed_updates'] = json.dumps(allowed_updates)
     return _make_request(token, method_url, params=payload)
 
 
@@ -414,9 +420,11 @@ def get_method_by_type(data_type):
         return r'sendSticker'
 
 
-def kick_chat_member(token, chat_id, user_id):
+def kick_chat_member(token, chat_id, user_id, until_date=None):
     method_url = 'kickChatMember'
     payload = {'chat_id': chat_id, 'user_id': user_id}
+    if until_date:
+        payload['until_date'] = until_date
     return _make_request(token, method_url, params=payload, method='post')
 
 
@@ -426,6 +434,75 @@ def unban_chat_member(token, chat_id, user_id):
     return _make_request(token, method_url, params=payload, method='post')
 
 
+def restrict_chat_member(token, chat_id, user_id, until_date=None, can_send_messages=True,
+                             can_send_media_messages=True, can_send_other_messages=True,
+                             can_add_web_page_previews=True):
+    method_url = 'restrictChatMember'
+    payload = {'chat_id': chat_id, 'user_id': user_id, 'until_date': until_date, 'can_send_messages': can_send_messages,
+               'can_send_media_messages': can_send_media_messages, 'can_send_other_messages': can_send_other_messages,
+               'can_add_web_page_previews': can_add_web_page_previews}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def promote_chat_member(token, chat_id, user_id, can_change_info=False, can_post_messages=False,
+                        can_edit_messages=False, can_delete_messages=False, can_invite_users=False,
+                        can_restrict_members=False, can_pin_messages=False, can_promote_members=False):
+    method_url = 'promoteChatMember'
+    payload = {'chat_id': chat_id, 'user_id': user_id, 'can_change_info': can_change_info,
+               'can_post_messages': can_post_messages, 'can_edit_messages': can_edit_messages,
+               'can_delete_messages': can_delete_messages, 'can_invite_users': can_invite_users,
+               'can_restrict_members': can_restrict_members, 'can_pin_messages': can_pin_messages,
+               'can_promote_members': can_promote_members }
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def export_chat_invite_link(token, chat_id):
+    method_url = 'exportChatInviteLink'
+    payload = {'chat_id': chat_id}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def set_chat_photo(token, chat_id, photo):
+    method_url = 'setChatPhoto'
+    payload = {'chat_id': chat_id}
+    files = None
+    if not util.is_string(photo):
+        files = {'photo': photo}
+    else:
+        payload['photo'] = photo
+    return _make_request(token, method_url, params=payload, files=files, method='post')
+
+
+def delete_chat_photo(token, chat_id):
+    method_url = 'deleteChatPhoto'
+    payload = {'chat_id': chat_id}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def set_chat_title(token, chat_id, title):
+    method_url = 'setChatTitle'
+    payload = {'chat_id': chat_id, 'title': title}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def set_chat_description(token, chat_id, description):
+    method_url = 'setChatDescription'
+    payload = {'chat_id': chat_id, 'description': description}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def pin_chat_message(token, chat_id, message_id, disable_notification=False):
+    method_url = 'pinChatMessage'
+    payload = {'chat_id': chat_id, 'message_id': message_id, 'disable_notification': disable_notification}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def unpin_chat_message(token, chat_id):
+    method_url = 'unpinChatMessage'
+    payload = {'chat_id': chat_id}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
 # Updating messages
 
 def edit_message_text(token, text, chat_id=None, message_id=None, inline_message_id=None, parse_mode=None,
